Module scheduler

Module scheduler 

Structs

DagScheduler
Event-driven DAG scheduler.
WorkflowState
In-memory workflow state that the frontend reads via polling.

Type Aliases

SharedState
Shared workflow state, readable by the frontend polling API.