Module scheduler
workflow_
graph_
queue
0.4.1
Module scheduler
Module Items
Structs
Type Aliases
In crate workflow_
graph_
queue
workflow_graph_queue
Module
scheduler
Structs

DagScheduler
Event-driven DAG scheduler.
Workflow
State
In-memory workflow state that the frontend reads via polling.
Type Aliases

Shared
State
Shared workflow state, readable by the frontend polling API.