Structs
- Lease
- A lease proving a worker has exclusively claimed a job.
- LogChunk
- A chunk of log output from a running job.
- Queued
Job - A job sitting in the queue, ready to be claimed by a worker.
- Retry
Policy - Configurable retry behavior per job.
- Worker
Info
Enums
- Backoff
Strategy - JobEvent
- Events emitted by the queue for the scheduler to react to.
- LogStream
- Worker
Status
Traits
- Artifact
Store - Pluggable artifact/output storage.
- JobQueue
- Pluggable job queue backend.
- LogSink
- Pluggable log storage and streaming backend.
- Worker
Registry - Registry of connected workers and their capabilities.